@@ -104,7 +104,7 @@ EXTERN_C_BEGIN
 
 /* prototypes */
 globus_result_t lcmaps_callout( va_list ap);
-static int llgt_run_lcas_authz_and_lcmaps_mapping (gss_ctx_id_t context, char ** local_identity);
+static int llgt_run_lcas_authz_and_lcmaps_mapping (gss_ctx_id_t context, char *desired_identity, char ** local_identity);
 
 /* -------- */
 
@@ -116,7 +116,7 @@ arguments:      gss_ctx_id_t context    - A context with all the credentials in
 Return:         1 : Error
                 0 : All is well
 ****************************************************/
-static int llgt_run_lcas_authz_and_lcmaps_mapping (gss_ctx_id_t context, char ** local_identity)
+static int llgt_run_lcas_authz_and_lcmaps_mapping (gss_ctx_id_t context, char *desired_identity, char ** local_identity)
 {
     int              retval             = 0;
     gss_cred_id_t    user_cred_handle   = GSS_C_NO_CREDENTIAL;
@@ -189,7 +189,7 @@ static int llgt_run_lcas_authz_and_lcmaps_mapping (gss_ctx_id_t context, char **
     llgt_create_jobid();
 
     /* Execute LCMAPS */
-    if (llgt_run_lcmaps(user_cred_handle, client_name, flog_lcmaps, local_identity)) {
+    if (llgt_run_lcmaps(user_cred_handle, client_name, flog_lcmaps, desired_identity, local_identity)) {
         llgt_logmsg(LOG_ERR, "Execution of LCMAPS failed.\n");
         free(client_name);
         retval = 1;
@@ -438,7 +438,7 @@ globus_result_t lcmaps_callout( va_list ap)
     /*************************
      * Start AuthZ with LCAS *
      *************************/
-    if (llgt_run_lcas_authz_and_lcmaps_mapping (context, &local_identity)) {
+    if (llgt_run_lcas_authz_and_lcmaps_mapping (context, desired_identity, &local_identity)) {
         /* llgt_logmsg(LOG_ERR, "Failure in Authorization and Mapping"); */
         result = (globus_result_t)GLOBUS_FAILURE;
         goto llgt_finalize;
