@@ -217,7 +217,7 @@ void llgt_setup_lcmaps_environment(void)
 }
 
 
-int llgt_run_lcmaps(gss_cred_id_t user_cred_handle, char * client_name, FILE * logfile, char ** username)
+int llgt_run_lcmaps(gss_cred_id_t user_cred_handle, char * client_name, FILE * logfile, char *desired_username, char ** username)
 {
     /* USER MAPPING */
     /* Define lcmaps_handle static so that we can reuse it */
@@ -230,6 +230,12 @@ int llgt_run_lcmaps(gss_cred_id_t user_cred_handle, char * client_name, FILE * l
 
     int i,npol=0;
     char **policies=NULL;
+    /* lcmaps library version */
+    int lcmaps_major,lcmaps_minor,lcmaps_patch;
+
+    int (*LcmapsMajorVersion)(void);
+    int (*LcmapsMinorVersion)(void);
+    int (*LcmapsPatchVersion)(void);
 
     int (*LcmapsInit)(FILE *);
     int (*LcmapsTerm)();
@@ -299,6 +305,21 @@ int llgt_run_lcmaps(gss_cred_id_t user_cred_handle, char * client_name, FILE * l
     if ((error = dlerror()) != NULL) {
 	llgt_logmsg(LOG_DEBUG, "LCMAPS module does not support explicit VOMS enable- or disablement. Symbol \"%s\" not found: %s", "lcmaps_disable_voms_attributes_verification", error);
     }
+    /* get_major_version, get_minor_version, get_patch_version: optional */
+    dlerror();
+    LcmapsMajorVersion=dlsym(lcmaps_handle,"lcmaps_get_major_version");
+    LcmapsMinorVersion=dlsym(lcmaps_handle,"lcmaps_get_minor_version");
+    LcmapsPatchVersion=dlsym(lcmaps_handle,"lcmaps_get_patch_version");
+    if ((error = dlerror()) != NULL) {
+	llgt_logmsg(LOG_WARNING, "LCMAPS module is old: Symbol lcmaps_get_major,-minor or -patch version not found: %s", error);
+	/* Default version: 0.0.0 */
+	lcmaps_major=lcmaps_minor=lcmaps_patch=0;
+    } else {
+	/* Get version */
+	lcmaps_major=LcmapsMajorVersion();
+	lcmaps_minor=LcmapsMinorVersion();
+	lcmaps_patch=LcmapsPatchVersion();
+    }
 
     /* Initialize LCMAPS, do user mapping and terminate LCMAPS */
     retval=(*LcmapsInit)(logfile);
@@ -326,6 +347,18 @@ int llgt_run_lcmaps(gss_cred_id_t user_cred_handle, char * client_name, FILE * l
 	npol=0;
     }
 
+    /* If LCMAPS version is >= 1.5.8, we can pass in the desired username */
+    if (lcmaps_major>1 ||
+	(lcmaps_major==1 &&
+	 (lcmaps_minor>5 || (lcmaps_minor==5 && lcmaps_patch>=8)))) {
+	/* When desired_username=="" make it NULL */
+	if (desired_username && strlen(desired_username)>0)
+	    *username=desired_username;
+	else
+	    *username=NULL;
+    } else /* Old LCMAPS, make it explicitly NULL */
+	*username=NULL;
+
 #if ALLOW_EMPTY_CREDENTIALS
     retval=(*LcmapsRunAndReturnUsername)(client_name,
 					 user_cred_handle,
